summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/pivottable.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/pivottable.cpp')
-rw-r--r--kmymoney2/reports/pivottable.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/reports/pivottable.cpp b/kmymoney2/reports/pivottable.cpp
index d39e226..bf048cb 100644
--- a/kmymoney2/reports/pivottable.cpp
+++ b/kmymoney2/reports/pivottable.cpp
@@ -783,7 +783,7 @@ MyMoneyMoney PivotTable::cellBalance(const TQString& outergroup, const ReportAcc
// ensure the row already exists (and its parental hierarchy)
createRow( outergroup, row, true );
// Determine the inner group from the top-most tqparent account
TQString innergroup( row.topParentName() );
if ( m_numColumns <= _column )
@@ -869,7 +869,7 @@ void PivotTable::calculateBudgetMapping( void )
m_budgetMap[acid] = id;
// kdDebug(2) << ReportAccount(acid).debugName() << " self-maps / type =" << budget.account(id).budgetLevel() << endl;
}
// Otherwise, search for a tqparent account which includes sub-accounts
else
{
//if includeBudgetActuals, include all accounts regardless of whether in budget or not
@@ -1248,7 +1248,7 @@ void PivotTable::assignCell( const TQString& outergroup, const ReportAccount& _r
// ensure the row already exists (and its parental hierarchy)
createRow( outergroup, row, true );
// Determine the inner group from the top-most tqparent account
TQString innergroup( row.topParentName() );
if ( m_numColumns <= column )
@@ -1276,7 +1276,7 @@ void PivotTable::createRow( const TQString& outergroup, const ReportAccount& row
{
DEBUG_ENTER(__PRETTY_FUNCTION__);
// Determine the inner group from the top-most tqparent account
TQString innergroup( row.topParentName() );
if ( ! m_grid.contains(outergroup) )
@@ -1297,7 +1297,7 @@ void PivotTable::createRow( const TQString& outergroup, const ReportAccount& row
m_grid[outergroup][innergroup][row] = PivotGridRowSet(m_numColumns);
if ( recursive && !row.isTopLevel() )
- createRow( outergroup, row.tqparent(), recursive );
+ createRow( outergroup, row.parent(), recursive );
}
}
@@ -1732,7 +1732,7 @@ TQString PivotTable::renderHTML( void ) const
if(!rowname.isClosed() || isUsed) {
innergroupdata += TQString("<tr class=\"row-%1\"%2><td%3 class=\"left\" style=\"text-indent: %4.0em\">%5%6</td>")
.tqarg(rownum & 0x01 ? "even" : "odd")
- .tqarg(rowname.isTopLevel() ? " id=\"toptqparent\"" : "")
+ .tqarg(rowname.isTopLevel() ? " id=\"topparent\"" : "")
.tqarg("") //.tqarg((*it_row).m_total.isZero() ? colspan : "") // colspan the distance if this row will be blank
.tqarg(rowname.hierarchyDepth() - 1)
.tqarg(rowname.name().replace(TQRegExp(" "), "&nbsp;"))
@@ -783,7 +783,7 @@ MyMoneyMoney PivotTable::cellBalance(const TQString& outergroup, const ReportAcc
// ensure the row already exists (and its parental hierarchy)
createRow( outergroup, row, true );
- // Determine the inner group from the top-most tqparent account
+ // Determine the inner group from the top-most parent account
TQString innergroup( row.topParentName() );
if ( m_numColumns <= _column )
@@ -869,7 +869,7 @@ void PivotTable::calculateBudgetMapping( void )
// kdDebug(2) << ReportAccount(acid).debugName() << " self-maps / type =" << budget.account(id).budgetLevel() << endl;
}
- // Otherwise, search for a tqparent account which includes sub-accounts
+ // Otherwise, search for a parent account which includes sub-accounts
else
{
@@ -1248,7 +1248,7 @@ void PivotTable::assignCell( const TQString& outergroup, const ReportAccount& _r
// ensure the row already exists (and its parental hierarchy)
createRow( outergroup, row, true );
- // Determine the inner group from the top-most tqparent account
+ // Determine the inner group from the top-most parent account
TQString innergroup( row.topParentName() );
if ( m_numColumns <= column )
@@ -1276,7 +1276,7 @@ void PivotTable::createRow( const TQString& outergroup, const ReportAccount& row
{
DEBUG_ENTER(__PRETTY_FUNCTION__);
- // Determine the inner group from the top-most tqparent account
+ // Determine the inner group from the top-most parent account
TQString innergroup( row.topParentName() );
if ( ! m_grid.contains(outergroup) )